pub struct BrowserObservation {
pub id: i64,
pub thread_id: String,
pub task_id: String,
pub run_id: String,
pub sequence_id: String,
pub observation: BrowserObservationData,
pub created_at: DateTime<Utc>,
}Fields
id: i64thread_id: Stringtask_id: Stringrun_id: Stringsequence_id: Stringobservation: BrowserObservationDatacreated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for BrowserObservation
impl Clone for BrowserObservation
Sourcefn clone(&self) -> BrowserObservation
fn clone(&self) -> BrowserObservation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowserObservation
impl Debug for BrowserObservation
Sourceimpl<'de> Deserialize<'de> for BrowserObservation
impl<'de> Deserialize<'de> for BrowserObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BrowserObservation
impl JsonSchema for BrowserObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BrowserObservation
impl RefUnwindSafe for BrowserObservation
impl Send for BrowserObservation
impl Sync for BrowserObservation
impl Unpin for BrowserObservation
impl UnsafeUnpin for BrowserObservation
impl UnwindSafe for BrowserObservation