pub struct BrowserSequence {
pub id: String,
pub goal: Option<String>,
pub task_id: Option<String>,
pub thread_id: Option<String>,
pub favourite: bool,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
}Fields
id: Stringgoal: Option<String>task_id: Option<String>thread_id: Option<String>favourite: boolcreated_at: DateTime<Utc>updated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for BrowserSequence
impl Clone for BrowserSequence
Sourcefn clone(&self) -> BrowserSequence
fn clone(&self) -> BrowserSequence
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowserSequence
impl Debug for BrowserSequence
Sourceimpl<'de> Deserialize<'de> for BrowserSequence
impl<'de> Deserialize<'de> for BrowserSequence
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BrowserSequence
impl JsonSchema for BrowserSequence
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BrowserSequence
impl RefUnwindSafe for BrowserSequence
impl Send for BrowserSequence
impl Sync for BrowserSequence
impl Unpin for BrowserSequence
impl UnwindSafe for BrowserSequence