pub struct NewBrowserObservation {
pub thread_id: String,
pub task_id: String,
pub run_id: String,
pub sequence_id: String,
pub observation: BrowserObservationData,
}Fields
thread_id: Stringtask_id: Stringrun_id: Stringsequence_id: Stringobservation: BrowserObservationDataTrait Implementations
Sourceimpl Clone for NewBrowserObservation
impl Clone for NewBrowserObservation
Sourcefn clone(&self) -> NewBrowserObservation
fn clone(&self) -> NewBrowserObservation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NewBrowserObservation
impl Debug for NewBrowserObservation
Sourceimpl<'de> Deserialize<'de> for NewBrowserObservation
impl<'de> Deserialize<'de> for NewBrowserObservation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NewBrowserObservation
impl JsonSchema for NewBrowserObservation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NewBrowserObservation
impl RefUnwindSafe for NewBrowserObservation
impl Send for NewBrowserObservation
impl Sync for NewBrowserObservation
impl Unpin for NewBrowserObservation
impl UnwindSafe for NewBrowserObservation