pub struct NewBrowserStep {Show 13 fields
pub id: String,
pub browser_sequence_id: String,
pub commands: Vec<Commands>,
pub reason: Option<String>,
pub thread_id: Option<String>,
pub task_id: Option<String>,
pub run_id: Option<String>,
pub thinking: Option<String>,
pub evaluation_previous_goal: Option<String>,
pub memory: Option<String>,
pub next_goal: Option<String>,
pub success: bool,
pub action_result: Option<Value>,
}Fields
id: Stringbrowser_sequence_id: Stringcommands: Vec<Commands>reason: Option<String>thread_id: Option<String>task_id: Option<String>run_id: Option<String>thinking: Option<String>evaluation_previous_goal: Option<String>memory: Option<String>next_goal: Option<String>success: boolaction_result: Option<Value>Trait Implementations
Sourceimpl Clone for NewBrowserStep
impl Clone for NewBrowserStep
Sourcefn clone(&self) -> NewBrowserStep
fn clone(&self) -> NewBrowserStep
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NewBrowserStep
impl Debug for NewBrowserStep
Sourceimpl<'de> Deserialize<'de> for NewBrowserStep
impl<'de> Deserialize<'de> for NewBrowserStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NewBrowserStep
impl JsonSchema for NewBrowserStep
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NewBrowserStep
impl RefUnwindSafe for NewBrowserStep
impl Send for NewBrowserStep
impl Sync for NewBrowserStep
impl Unpin for NewBrowserStep
impl UnsafeUnpin for NewBrowserStep
impl UnwindSafe for NewBrowserStep