pub struct BoundingBoxElement {
pub selector: String,
pub index: usize,
pub tag: String,
pub text: Option<String>,
pub attributes: Value,
pub bounding_box: ElementBox,
pub center: CommandPoint,
pub visibility: bool,
pub clickable: bool,
pub html: Option<String>,
}Fields
selector: Stringindex: usizetag: Stringtext: Option<String>attributes: Valuebounding_box: ElementBoxcenter: CommandPointvisibility: boolclickable: boolhtml: Option<String>Trait Implementations
Sourceimpl Clone for BoundingBoxElement
impl Clone for BoundingBoxElement
Sourcefn clone(&self) -> BoundingBoxElement
fn clone(&self) -> BoundingBoxElement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BoundingBoxElement
impl Debug for BoundingBoxElement
Sourceimpl<'de> Deserialize<'de> for BoundingBoxElement
impl<'de> Deserialize<'de> for BoundingBoxElement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BoundingBoxElement
impl JsonSchema for BoundingBoxElement
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BoundingBoxElement
impl RefUnwindSafe for BoundingBoxElement
impl Send for BoundingBoxElement
impl Sync for BoundingBoxElement
impl Unpin for BoundingBoxElement
impl UnsafeUnpin for BoundingBoxElement
impl UnwindSafe for BoundingBoxElement