pub struct BrowserContext {
pub thread_id: Option<String>,
pub task_id: Option<String>,
pub run_id: Option<String>,
pub model_settings: Option<Value>,
pub distri_client_config: Option<Value>,
}Expand description
Context to enrich structured extraction calls with thread metadata and model settings
Fields
thread_id: Option<String>task_id: Option<String>run_id: Option<String>model_settings: Option<Value>distri_client_config: Option<Value>Trait Implementations
Sourceimpl Clone for BrowserContext
impl Clone for BrowserContext
Sourcefn clone(&self) -> BrowserContext
fn clone(&self) -> BrowserContext
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowserContext
impl Debug for BrowserContext
Sourceimpl Default for BrowserContext
impl Default for BrowserContext
Sourcefn default() -> BrowserContext
fn default() -> BrowserContext
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BrowserContext
impl<'de> Deserialize<'de> for BrowserContext
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BrowserContext
impl JsonSchema for BrowserContext
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BrowserContext
impl RefUnwindSafe for BrowserContext
impl Send for BrowserContext
impl Sync for BrowserContext
impl Unpin for BrowserContext
impl UnwindSafe for BrowserContext