pub struct BrowserCookie {
pub name: String,
pub value: String,
pub domain: Option<String>,
pub path: Option<String>,
pub expires: Option<f64>,
pub http_only: bool,
pub secure: bool,
pub same_site: Option<String>,
pub priority: Option<String>,
pub source_scheme: Option<String>,
}Expand description
Serializable cookie representation used for session persistence
Fields
name: Stringvalue: Stringdomain: Option<String>path: Option<String>expires: Option<f64>http_only: boolsecure: boolsame_site: Option<String>priority: Option<String>source_scheme: Option<String>Trait Implementations
Sourceimpl Clone for BrowserCookie
impl Clone for BrowserCookie
Sourcefn clone(&self) -> BrowserCookie
fn clone(&self) -> BrowserCookie
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowserCookie
impl Debug for BrowserCookie
Sourceimpl<'de> Deserialize<'de> for BrowserCookie
impl<'de> Deserialize<'de> for BrowserCookie
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BrowserCookie
impl JsonSchema for BrowserCookie
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BrowserCookie
impl RefUnwindSafe for BrowserCookie
impl Send for BrowserCookie
impl Sync for BrowserCookie
impl Unpin for BrowserCookie
impl UnsafeUnpin for BrowserCookie
impl UnwindSafe for BrowserCookie