pub struct BrowserSessionRecord {
pub user_id: String,
pub state: BrowserSessionState,
pub updated_at: DateTime<Utc>,
}Expand description
Persisted browser session entry keyed by user id
Fields
user_id: Stringstate: BrowserSessionStateupdated_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for BrowserSessionRecord
impl Clone for BrowserSessionRecord
Sourcefn clone(&self) -> BrowserSessionRecord
fn clone(&self) -> BrowserSessionRecord
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowserSessionRecord
impl Debug for BrowserSessionRecord
Sourceimpl<'de> Deserialize<'de> for BrowserSessionRecord
impl<'de> Deserialize<'de> for BrowserSessionRecord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BrowserSessionRecord
impl JsonSchema for BrowserSessionRecord
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BrowserSessionRecord
impl RefUnwindSafe for BrowserSessionRecord
impl Send for BrowserSessionRecord
impl Sync for BrowserSessionRecord
impl Unpin for BrowserSessionRecord
impl UnsafeUnpin for BrowserSessionRecord
impl UnwindSafe for BrowserSessionRecord