pub struct BrowserSessionState {
pub cookies: Vec<BrowserCookie>,
pub last_url: Option<String>,
pub captured_at: DateTime<Utc>,
}Expand description
Captured browser state (cookies + last URL)
Fields
last_url: Option<String>captured_at: DateTime<Utc>Trait Implementations
Sourceimpl Clone for BrowserSessionState
impl Clone for BrowserSessionState
Sourcefn clone(&self) -> BrowserSessionState
fn clone(&self) -> BrowserSessionState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowserSessionState
impl Debug for BrowserSessionState
Sourceimpl<'de> Deserialize<'de> for BrowserSessionState
impl<'de> Deserialize<'de> for BrowserSessionState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BrowserSessionState
impl JsonSchema for BrowserSessionState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BrowserSessionState
impl RefUnwindSafe for BrowserSessionState
impl Send for BrowserSessionState
impl Sync for BrowserSessionState
impl Unpin for BrowserSessionState
impl UnwindSafe for BrowserSessionState