pub struct BrowserToolOptions {
pub commands: Vec<Commands>,
pub context: Option<BrowserContext>,
}Fields
commands: Vec<Commands>context: Option<BrowserContext>Trait Implementations
Sourceimpl Clone for BrowserToolOptions
impl Clone for BrowserToolOptions
Sourcefn clone(&self) -> BrowserToolOptions
fn clone(&self) -> BrowserToolOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BrowserToolOptions
impl Debug for BrowserToolOptions
Sourceimpl Default for BrowserToolOptions
impl Default for BrowserToolOptions
Sourcefn default() -> BrowserToolOptions
fn default() -> BrowserToolOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BrowserToolOptions
impl<'de> Deserialize<'de> for BrowserToolOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Commands> for BrowserToolOptions
impl From<Commands> for BrowserToolOptions
Sourceimpl JsonSchema for BrowserToolOptions
impl JsonSchema for BrowserToolOptions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BrowserToolOptions
impl RefUnwindSafe for BrowserToolOptions
impl Send for BrowserToolOptions
impl Sync for BrowserToolOptions
impl Unpin for BrowserToolOptions
impl UnwindSafe for BrowserToolOptions