pub struct ClickTarget {
pub target_id: String,
pub tag: String,
pub text: Option<String>,
pub attributes: Option<Map<String, Value>>,
pub bounding_box: ElementBox,
pub center: CommandPoint,
}Fields
target_id: Stringtag: Stringtext: Option<String>attributes: Option<Map<String, Value>>bounding_box: ElementBoxcenter: CommandPointTrait Implementations
Sourceimpl Clone for ClickTarget
impl Clone for ClickTarget
Sourcefn clone(&self) -> ClickTarget
fn clone(&self) -> ClickTarget
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClickTarget
impl Debug for ClickTarget
Sourceimpl<'de> Deserialize<'de> for ClickTarget
impl<'de> Deserialize<'de> for ClickTarget
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClickTarget
impl JsonSchema for ClickTarget
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ClickTarget
impl RefUnwindSafe for ClickTarget
impl Send for ClickTarget
impl Sync for ClickTarget
impl Unpin for ClickTarget
impl UnsafeUnpin for ClickTarget
impl UnwindSafe for ClickTarget