pub struct CommandPoint {
pub x: f64,
pub y: f64,
}Fields
x: f64y: f64Trait Implementations
Sourceimpl Clone for CommandPoint
impl Clone for CommandPoint
Sourcefn clone(&self) -> CommandPoint
fn clone(&self) -> CommandPoint
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandPoint
impl Debug for CommandPoint
Sourceimpl<'de> Deserialize<'de> for CommandPoint
impl<'de> Deserialize<'de> for CommandPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CommandPoint
impl JsonSchema for CommandPoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommandPoint
impl RefUnwindSafe for CommandPoint
impl Send for CommandPoint
impl Sync for CommandPoint
impl Unpin for CommandPoint
impl UnwindSafe for CommandPoint