pub struct CrawlResponse {
pub success: bool,
pub command: String,
pub data: Option<CrawlData>,
pub error: Option<String>,
}Fields
success: boolcommand: Stringdata: Option<CrawlData>error: Option<String>Trait Implementations
Sourceimpl Clone for CrawlResponse
impl Clone for CrawlResponse
Sourcefn clone(&self) -> CrawlResponse
fn clone(&self) -> CrawlResponse
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CrawlResponse
impl Debug for CrawlResponse
Sourceimpl<'de> Deserialize<'de> for CrawlResponse
impl<'de> Deserialize<'de> for CrawlResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CrawlResponse
impl JsonSchema for CrawlResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CrawlResponse
impl RefUnwindSafe for CrawlResponse
impl Send for CrawlResponse
impl Sync for CrawlResponse
impl Unpin for CrawlResponse
impl UnwindSafe for CrawlResponse