pub struct ElementBox {
pub x: f64,
pub y: f64,
pub width: f64,
pub height: f64,
}Fields
x: f64y: f64width: f64height: f64Trait Implementations
Sourceimpl Clone for ElementBox
impl Clone for ElementBox
Sourcefn clone(&self) -> ElementBox
fn clone(&self) -> ElementBox
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ElementBox
impl Debug for ElementBox
Sourceimpl<'de> Deserialize<'de> for ElementBox
impl<'de> Deserialize<'de> for ElementBox
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ElementBox
impl JsonSchema for ElementBox
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ElementBox
impl RefUnwindSafe for ElementBox
impl Send for ElementBox
impl Sync for ElementBox
impl Unpin for ElementBox
impl UnsafeUnpin for ElementBox
impl UnwindSafe for ElementBox