pub struct ExtractedImage {
pub src: String,
pub alt: Option<String>,
}Fields
src: Stringalt: Option<String>Trait Implementations
Sourceimpl Clone for ExtractedImage
impl Clone for ExtractedImage
Sourcefn clone(&self) -> ExtractedImage
fn clone(&self) -> ExtractedImage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractedImage
impl Debug for ExtractedImage
Sourceimpl<'de> Deserialize<'de> for ExtractedImage
impl<'de> Deserialize<'de> for ExtractedImage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractedImage
impl JsonSchema for ExtractedImage
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExtractedImage
impl RefUnwindSafe for ExtractedImage
impl Send for ExtractedImage
impl Sync for ExtractedImage
impl Unpin for ExtractedImage
impl UnsafeUnpin for ExtractedImage
impl UnwindSafe for ExtractedImage