pub struct ExtractedLink {
pub href: String,
pub text: String,
}Fields
href: Stringtext: StringTrait Implementations
Sourceimpl Clone for ExtractedLink
impl Clone for ExtractedLink
Sourcefn clone(&self) -> ExtractedLink
fn clone(&self) -> ExtractedLink
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractedLink
impl Debug for ExtractedLink
Sourceimpl<'de> Deserialize<'de> for ExtractedLink
impl<'de> Deserialize<'de> for ExtractedLink
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractedLink
impl JsonSchema for ExtractedLink
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExtractedLink
impl RefUnwindSafe for ExtractedLink
impl Send for ExtractedLink
impl Sync for ExtractedLink
impl Unpin for ExtractedLink
impl UnsafeUnpin for ExtractedLink
impl UnwindSafe for ExtractedLink