pub struct HtmlSelectorResult {
pub selector: String,
pub html: String,
}Fields
selector: Stringhtml: StringTrait Implementations
Sourceimpl Clone for HtmlSelectorResult
impl Clone for HtmlSelectorResult
Sourcefn clone(&self) -> HtmlSelectorResult
fn clone(&self) -> HtmlSelectorResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HtmlSelectorResult
impl Debug for HtmlSelectorResult
Sourceimpl<'de> Deserialize<'de> for HtmlSelectorResult
impl<'de> Deserialize<'de> for HtmlSelectorResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HtmlSelectorResult
impl JsonSchema for HtmlSelectorResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HtmlSelectorResult
impl RefUnwindSafe for HtmlSelectorResult
impl Send for HtmlSelectorResult
impl Sync for HtmlSelectorResult
impl Unpin for HtmlSelectorResult
impl UnsafeUnpin for HtmlSelectorResult
impl UnwindSafe for HtmlSelectorResult