pub struct JsonExtractionOptions {
pub prompt: Option<String>,
pub schema: Option<Value>,
}Fields
prompt: Option<String>schema: Option<Value>Trait Implementations
Sourceimpl Clone for JsonExtractionOptions
impl Clone for JsonExtractionOptions
Sourcefn clone(&self) -> JsonExtractionOptions
fn clone(&self) -> JsonExtractionOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsonExtractionOptions
impl Debug for JsonExtractionOptions
Sourceimpl<'de> Deserialize<'de> for JsonExtractionOptions
impl<'de> Deserialize<'de> for JsonExtractionOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for JsonExtractionOptions
impl JsonSchema for JsonExtractionOptions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for JsonExtractionOptions
impl RefUnwindSafe for JsonExtractionOptions
impl Send for JsonExtractionOptions
impl Sync for JsonExtractionOptions
impl Unpin for JsonExtractionOptions
impl UnsafeUnpin for JsonExtractionOptions
impl UnwindSafe for JsonExtractionOptions