pub struct LocalStorageItem {
pub key: String,
pub value: String,
}Expand description
A single localStorage or sessionStorage item
Fields
key: Stringvalue: StringTrait Implementations
Sourceimpl Clone for LocalStorageItem
impl Clone for LocalStorageItem
Sourcefn clone(&self) -> LocalStorageItem
fn clone(&self) -> LocalStorageItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocalStorageItem
impl Debug for LocalStorageItem
Sourceimpl<'de> Deserialize<'de> for LocalStorageItem
impl<'de> Deserialize<'de> for LocalStorageItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LocalStorageItem
impl JsonSchema for LocalStorageItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LocalStorageItem
impl RefUnwindSafe for LocalStorageItem
impl Send for LocalStorageItem
impl Sync for LocalStorageItem
impl Unpin for LocalStorageItem
impl UnsafeUnpin for LocalStorageItem
impl UnwindSafe for LocalStorageItem