pub struct MountPoint {
pub storage_path: String,
pub container_path: String,
pub max_size_mb: u32,
}Expand description
Mount point for input/output data volumes.
Fields
storage_path: Stringcontainer_path: Stringmax_size_mb: u32Trait Implementations
Sourceimpl Clone for MountPoint
impl Clone for MountPoint
Sourcefn clone(&self) -> MountPoint
fn clone(&self) -> MountPoint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MountPoint
impl Debug for MountPoint
Sourceimpl<'de> Deserialize<'de> for MountPoint
impl<'de> Deserialize<'de> for MountPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MountPoint
impl JsonSchema for MountPoint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MountPoint
impl RefUnwindSafe for MountPoint
impl Send for MountPoint
impl Sync for MountPoint
impl Unpin for MountPoint
impl UnsafeUnpin for MountPoint
impl UnwindSafe for MountPoint