pub struct QueryResult {
pub query: String,
pub follow_up_questions: Option<Vec<String>>,
pub answer: Option<String>,
pub images: Vec<String>,
pub results: Vec<SearchResult>,
}Fields
query: Stringfollow_up_questions: Option<Vec<String>>answer: Option<String>images: Vec<String>results: Vec<SearchResult>Trait Implementations
Sourceimpl Debug for QueryResult
impl Debug for QueryResult
Sourceimpl<'de> Deserialize<'de> for QueryResult
impl<'de> Deserialize<'de> for QueryResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QueryResult
impl JsonSchema for QueryResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for QueryResult
impl RefUnwindSafe for QueryResult
impl Send for QueryResult
impl Sync for QueryResult
impl Unpin for QueryResult
impl UnsafeUnpin for QueryResult
impl UnwindSafe for QueryResult