pub struct RelayEvent {
pub ts: i64,
pub session_id: String,
pub category: String,
pub method: Option<String>,
pub level: Option<String>,
pub summary: Option<String>,
pub payload: Value,
}Fields
ts: i64session_id: Stringcategory: Stringmethod: Option<String>level: Option<String>summary: Option<String>payload: ValueTrait Implementations
Sourceimpl Clone for RelayEvent
impl Clone for RelayEvent
Sourcefn clone(&self) -> RelayEvent
fn clone(&self) -> RelayEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelayEvent
impl Debug for RelayEvent
Sourceimpl<'de> Deserialize<'de> for RelayEvent
impl<'de> Deserialize<'de> for RelayEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RelayEvent
impl JsonSchema for RelayEvent
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelayEvent
impl RefUnwindSafe for RelayEvent
impl Send for RelayEvent
impl Sync for RelayEvent
impl Unpin for RelayEvent
impl UnsafeUnpin for RelayEvent
impl UnwindSafe for RelayEvent