pub struct RelayEventsResponse {
pub session_id: String,
pub count: usize,
pub events: Vec<RelayEvent>,
}Fields
session_id: Stringcount: usizeevents: Vec<RelayEvent>Trait Implementations
Sourceimpl Clone for RelayEventsResponse
impl Clone for RelayEventsResponse
Sourcefn clone(&self) -> RelayEventsResponse
fn clone(&self) -> RelayEventsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelayEventsResponse
impl Debug for RelayEventsResponse
Sourceimpl<'de> Deserialize<'de> for RelayEventsResponse
impl<'de> Deserialize<'de> for RelayEventsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RelayEventsResponse
impl JsonSchema for RelayEventsResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelayEventsResponse
impl RefUnwindSafe for RelayEventsResponse
impl Send for RelayEventsResponse
impl Sync for RelayEventsResponse
impl Unpin for RelayEventsResponse
impl UnsafeUnpin for RelayEventsResponse
impl UnwindSafe for RelayEventsResponse