pub struct RelaySessionInfo {
pub session_id: String,
pub connected: bool,
pub connected_at: i64,
pub last_activity: Option<i64>,
pub idle_secs: Option<i64>,
pub user_email: Option<String>,
pub tab_url: Option<String>,
pub tab_title: Option<String>,
}Fields
session_id: Stringconnected: boolconnected_at: i64last_activity: Option<i64>idle_secs: Option<i64>user_email: Option<String>tab_url: Option<String>tab_title: Option<String>Trait Implementations
Sourceimpl Clone for RelaySessionInfo
impl Clone for RelaySessionInfo
Sourcefn clone(&self) -> RelaySessionInfo
fn clone(&self) -> RelaySessionInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelaySessionInfo
impl Debug for RelaySessionInfo
Sourceimpl<'de> Deserialize<'de> for RelaySessionInfo
impl<'de> Deserialize<'de> for RelaySessionInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RelaySessionInfo
impl JsonSchema for RelaySessionInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelaySessionInfo
impl RefUnwindSafe for RelaySessionInfo
impl Send for RelaySessionInfo
impl Sync for RelaySessionInfo
impl Unpin for RelaySessionInfo
impl UnsafeUnpin for RelaySessionInfo
impl UnwindSafe for RelaySessionInfo