pub struct RelaySessionListResponse {
pub sessions: Vec<RelaySessionInfo>,
}Fields
sessions: Vec<RelaySessionInfo>Trait Implementations
Sourceimpl Clone for RelaySessionListResponse
impl Clone for RelaySessionListResponse
Sourcefn clone(&self) -> RelaySessionListResponse
fn clone(&self) -> RelaySessionListResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RelaySessionListResponse
impl Debug for RelaySessionListResponse
Sourceimpl<'de> Deserialize<'de> for RelaySessionListResponse
impl<'de> Deserialize<'de> for RelaySessionListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RelaySessionListResponse
impl JsonSchema for RelaySessionListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RelaySessionListResponse
impl RefUnwindSafe for RelaySessionListResponse
impl Send for RelaySessionListResponse
impl Sync for RelaySessionListResponse
impl Unpin for RelaySessionListResponse
impl UnsafeUnpin for RelaySessionListResponse
impl UnwindSafe for RelaySessionListResponse