pub struct ScrapeData {
pub markdown: Option<String>,
pub summary: Option<String>,
pub html: Option<String>,
pub raw_html: Option<String>,
pub screenshot: Option<String>,
pub links: Option<Vec<ExtractedLink>>,
pub json: Option<Value>,
pub images: Option<Vec<ExtractedImage>>,
pub branding: Option<BrandingInfo>,
pub metadata: PageMetadata,
pub warning: Option<String>,
}Fields
markdown: Option<String>summary: Option<String>html: Option<String>raw_html: Option<String>screenshot: Option<String>links: Option<Vec<ExtractedLink>>json: Option<Value>images: Option<Vec<ExtractedImage>>branding: Option<BrandingInfo>metadata: PageMetadatawarning: Option<String>Trait Implementations
Sourceimpl Clone for ScrapeData
impl Clone for ScrapeData
Sourcefn clone(&self) -> ScrapeData
fn clone(&self) -> ScrapeData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScrapeData
impl Debug for ScrapeData
Sourceimpl<'de> Deserialize<'de> for ScrapeData
impl<'de> Deserialize<'de> for ScrapeData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScrapeData
impl JsonSchema for ScrapeData
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScrapeData
impl RefUnwindSafe for ScrapeData
impl Send for ScrapeData
impl Sync for ScrapeData
impl Unpin for ScrapeData
impl UnsafeUnpin for ScrapeData
impl UnwindSafe for ScrapeData