pub struct ScrapeOptions {
pub url: String,
pub use_js: Option<bool>,
pub wait_for: Option<u64>,
pub extract_links: Option<bool>,
pub selector: Option<String>,
pub extract_images: Option<bool>,
pub extract_metadata: Option<bool>,
pub extract_tables: Option<bool>,
pub extract_forms: Option<bool>,
pub extract_structured_data: Option<bool>,
pub readable_content: Option<bool>,
pub remove_base64_images: Option<bool>,
}Expand description
Crawl command parameters
Fields
url: Stringuse_js: Option<bool>wait_for: Option<u64>extract_links: Option<bool>selector: Option<String>extract_images: Option<bool>extract_metadata: Option<bool>extract_tables: Option<bool>extract_forms: Option<bool>extract_structured_data: Option<bool>readable_content: Option<bool>remove_base64_images: Option<bool>Trait Implementations
Sourceimpl Clone for ScrapeOptions
impl Clone for ScrapeOptions
Sourcefn clone(&self) -> ScrapeOptions
fn clone(&self) -> ScrapeOptions
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScrapeOptions
impl Debug for ScrapeOptions
Sourceimpl Default for ScrapeOptions
impl Default for ScrapeOptions
Sourcefn default() -> ScrapeOptions
fn default() -> ScrapeOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ScrapeOptions
impl<'de> Deserialize<'de> for ScrapeOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScrapeOptions
impl JsonSchema for ScrapeOptions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScrapeOptions
impl RefUnwindSafe for ScrapeOptions
impl Send for ScrapeOptions
impl Sync for ScrapeOptions
impl Unpin for ScrapeOptions
impl UnwindSafe for ScrapeOptions