pub struct SearchData {
pub query: String,
pub answer: Option<String>,
pub results: Vec<SearchResult>,
pub results_count: usize,
}Fields
query: Stringanswer: Option<String>results: Vec<SearchResult>results_count: usizeTrait Implementations
Sourceimpl Clone for SearchData
impl Clone for SearchData
Sourcefn clone(&self) -> SearchData
fn clone(&self) -> SearchData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchData
impl Debug for SearchData
Sourceimpl<'de> Deserialize<'de> for SearchData
impl<'de> Deserialize<'de> for SearchData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchData
impl JsonSchema for SearchData
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchData
impl RefUnwindSafe for SearchData
impl Send for SearchData
impl Sync for SearchData
impl Unpin for SearchData
impl UnsafeUnpin for SearchData
impl UnwindSafe for SearchData