pub struct SearchOptions {
pub query: String,
pub limit: Option<usize>,
}Fields
query: Stringlimit: Option<usize>Trait Implementations
Sourceimpl Clone for SearchOptions
impl Clone for SearchOptions
Sourcefn clone(&self) -> SearchOptions
fn clone(&self) -> SearchOptions
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchOptions
impl Debug for SearchOptions
Sourceimpl Default for SearchOptions
impl Default for SearchOptions
Sourcefn default() -> SearchOptions
fn default() -> SearchOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SearchOptions
impl<'de> Deserialize<'de> for SearchOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SearchOptions
impl JsonSchema for SearchOptions
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SearchOptions
impl RefUnwindSafe for SearchOptions
impl Send for SearchOptions
impl Sync for SearchOptions
impl Unpin for SearchOptions
impl UnwindSafe for SearchOptions