pub struct ShellCreateSessionRequest {Show 17 fields
pub environment_id: Option<String>,
pub image: Option<String>,
pub memory_mb: Option<u32>,
pub disk_mb: Option<u32>,
pub cpu_cores: Option<f32>,
pub language: Option<String>,
pub timeout_secs: Option<u32>,
pub working_dir: Option<String>,
pub input_mounts: Option<Vec<MountPoint>>,
pub output_mounts: Option<Vec<MountPoint>>,
pub tools: Option<Vec<ToolDefinition>>,
pub tools_endpoint: Option<String>,
pub tool_timeout_secs: Option<u32>,
pub setup_script: Option<String>,
pub cache_paths: Option<Vec<String>>,
pub network_access: Option<NetworkAccess>,
pub env_vars: Option<HashMap<String, String>>,
}Fields
environment_id: Option<String>image: Option<String>memory_mb: Option<u32>disk_mb: Option<u32>cpu_cores: Option<f32>language: Option<String>timeout_secs: Option<u32>working_dir: Option<String>input_mounts: Option<Vec<MountPoint>>output_mounts: Option<Vec<MountPoint>>tools: Option<Vec<ToolDefinition>>tools_endpoint: Option<String>tool_timeout_secs: Option<u32>setup_script: Option<String>cache_paths: Option<Vec<String>>network_access: Option<NetworkAccess>env_vars: Option<HashMap<String, String>>Trait Implementations
Sourceimpl Clone for ShellCreateSessionRequest
impl Clone for ShellCreateSessionRequest
Sourcefn clone(&self) -> ShellCreateSessionRequest
fn clone(&self) -> ShellCreateSessionRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellCreateSessionRequest
impl Debug for ShellCreateSessionRequest
Sourceimpl Default for ShellCreateSessionRequest
impl Default for ShellCreateSessionRequest
Sourcefn default() -> ShellCreateSessionRequest
fn default() -> ShellCreateSessionRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ShellCreateSessionRequest
impl<'de> Deserialize<'de> for ShellCreateSessionRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellCreateSessionRequest
impl JsonSchema for ShellCreateSessionRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShellCreateSessionRequest
impl RefUnwindSafe for ShellCreateSessionRequest
impl Send for ShellCreateSessionRequest
impl Sync for ShellCreateSessionRequest
impl Unpin for ShellCreateSessionRequest
impl UnsafeUnpin for ShellCreateSessionRequest
impl UnwindSafe for ShellCreateSessionRequest