pub struct ShellExecRequest {
pub session_id: String,
pub command: String,
pub timeout_secs: Option<u32>,
pub working_dir: Option<String>,
}Fields
session_id: Stringcommand: Stringtimeout_secs: Option<u32>working_dir: Option<String>Trait Implementations
Sourceimpl Clone for ShellExecRequest
impl Clone for ShellExecRequest
Sourcefn clone(&self) -> ShellExecRequest
fn clone(&self) -> ShellExecRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellExecRequest
impl Debug for ShellExecRequest
Sourceimpl<'de> Deserialize<'de> for ShellExecRequest
impl<'de> Deserialize<'de> for ShellExecRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellExecRequest
impl JsonSchema for ShellExecRequest
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShellExecRequest
impl RefUnwindSafe for ShellExecRequest
impl Send for ShellExecRequest
impl Sync for ShellExecRequest
impl Unpin for ShellExecRequest
impl UnsafeUnpin for ShellExecRequest
impl UnwindSafe for ShellExecRequest