pub struct ShellExecResponse {
pub session_id: String,
pub result: ShellExecResult,
}Fields
session_id: Stringresult: ShellExecResultTrait Implementations
Sourceimpl Clone for ShellExecResponse
impl Clone for ShellExecResponse
Sourcefn clone(&self) -> ShellExecResponse
fn clone(&self) -> ShellExecResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellExecResponse
impl Debug for ShellExecResponse
Sourceimpl<'de> Deserialize<'de> for ShellExecResponse
impl<'de> Deserialize<'de> for ShellExecResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellExecResponse
impl JsonSchema for ShellExecResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShellExecResponse
impl RefUnwindSafe for ShellExecResponse
impl Send for ShellExecResponse
impl Sync for ShellExecResponse
impl Unpin for ShellExecResponse
impl UnsafeUnpin for ShellExecResponse
impl UnwindSafe for ShellExecResponse