pub struct ShellExecResult {
pub stdout: String,
pub stderr: String,
pub exit_code: Option<i32>,
pub duration_ms: Option<u64>,
pub timed_out: bool,
}Fields
stdout: Stringstderr: Stringexit_code: Option<i32>duration_ms: Option<u64>timed_out: boolTrait Implementations
Sourceimpl Clone for ShellExecResult
impl Clone for ShellExecResult
Sourcefn clone(&self) -> ShellExecResult
fn clone(&self) -> ShellExecResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellExecResult
impl Debug for ShellExecResult
Sourceimpl<'de> Deserialize<'de> for ShellExecResult
impl<'de> Deserialize<'de> for ShellExecResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellExecResult
impl JsonSchema for ShellExecResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShellExecResult
impl RefUnwindSafe for ShellExecResult
impl Send for ShellExecResult
impl Sync for ShellExecResult
impl Unpin for ShellExecResult
impl UnsafeUnpin for ShellExecResult
impl UnwindSafe for ShellExecResult