pub struct ShellListResponse {
pub shells: Vec<ShellListItem>,
}Fields
shells: Vec<ShellListItem>Trait Implementations
Sourceimpl Clone for ShellListResponse
impl Clone for ShellListResponse
Sourcefn clone(&self) -> ShellListResponse
fn clone(&self) -> ShellListResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellListResponse
impl Debug for ShellListResponse
Sourceimpl<'de> Deserialize<'de> for ShellListResponse
impl<'de> Deserialize<'de> for ShellListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellListResponse
impl JsonSchema for ShellListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShellListResponse
impl RefUnwindSafe for ShellListResponse
impl Send for ShellListResponse
impl Sync for ShellListResponse
impl Unpin for ShellListResponse
impl UnsafeUnpin for ShellListResponse
impl UnwindSafe for ShellListResponse