pub struct ShellSessionListItem {
pub session_id: String,
pub status: String,
pub image: String,
pub created_at: String,
pub last_activity: String,
}Fields
session_id: Stringstatus: Stringimage: Stringcreated_at: Stringlast_activity: StringTrait Implementations
Sourceimpl Clone for ShellSessionListItem
impl Clone for ShellSessionListItem
Sourcefn clone(&self) -> ShellSessionListItem
fn clone(&self) -> ShellSessionListItem
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellSessionListItem
impl Debug for ShellSessionListItem
Sourceimpl<'de> Deserialize<'de> for ShellSessionListItem
impl<'de> Deserialize<'de> for ShellSessionListItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellSessionListItem
impl JsonSchema for ShellSessionListItem
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShellSessionListItem
impl RefUnwindSafe for ShellSessionListItem
impl Send for ShellSessionListItem
impl Sync for ShellSessionListItem
impl Unpin for ShellSessionListItem
impl UnsafeUnpin for ShellSessionListItem
impl UnwindSafe for ShellSessionListItem