pub struct ShellSessionListResponse {
pub sessions: Vec<ShellSessionListItem>,
}Fields
sessions: Vec<ShellSessionListItem>Trait Implementations
Sourceimpl Clone for ShellSessionListResponse
impl Clone for ShellSessionListResponse
Sourcefn clone(&self) -> ShellSessionListResponse
fn clone(&self) -> ShellSessionListResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ShellSessionListResponse
impl Debug for ShellSessionListResponse
Sourceimpl<'de> Deserialize<'de> for ShellSessionListResponse
impl<'de> Deserialize<'de> for ShellSessionListResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShellSessionListResponse
impl JsonSchema for ShellSessionListResponse
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShellSessionListResponse
impl RefUnwindSafe for ShellSessionListResponse
impl Send for ShellSessionListResponse
impl Sync for ShellSessionListResponse
impl Unpin for ShellSessionListResponse
impl UnsafeUnpin for ShellSessionListResponse
impl UnwindSafe for ShellSessionListResponse