pub struct WaitForElementCheck {
pub found: bool,
pub visible: bool,
}Fields
found: boolvisible: boolTrait Implementations
Sourceimpl Clone for WaitForElementCheck
impl Clone for WaitForElementCheck
Sourcefn clone(&self) -> WaitForElementCheck
fn clone(&self) -> WaitForElementCheck
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WaitForElementCheck
impl Debug for WaitForElementCheck
Sourceimpl<'de> Deserialize<'de> for WaitForElementCheck
impl<'de> Deserialize<'de> for WaitForElementCheck
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for WaitForElementCheck
impl JsonSchema for WaitForElementCheck
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WaitForElementCheck
impl RefUnwindSafe for WaitForElementCheck
impl Send for WaitForElementCheck
impl Sync for WaitForElementCheck
impl Unpin for WaitForElementCheck
impl UnsafeUnpin for WaitForElementCheck
impl UnwindSafe for WaitForElementCheck